contexttools.get_context_marks_attached_to_any_improper_parent_of_component
===========================================================================

.. autofunction:: abjad.tools.contexttools.get_context_marks_attached_to_any_improper_parent_of_component.get_context_marks_attached_to_any_improper_parent_of_component
